@@ -142,8 +142,8 @@ class MapCanvas(basemap.Basemap):
         if self.appearance["draw_graticule"]:
             try:
                 self._draw_auto_graticule()
-            except Exception, e:
-                logging.error("ERROR: cannot plot graticule (message: %s)" % e)
+            except Exception, ex:
+                logging.error("ERROR: cannot plot graticule (message: %s)", ex)
         else:
             self.map_parallels = None
             self.map_meridians = None
@@ -405,11 +405,9 @@ class MapCanvas(basemap.Basemap):
         self.kwargs['urcrnrlon'], self.kwargs['urcrnrlat'] = \
             self.__call__(axis[1], axis[3], inverse=True)
 
-        logging.debug("corner coordinates (lat/lon): ll(%.2f,%.2f), "
-                      "ur(%.2f,%.2f)" % (self.kwargs['llcrnrlat'],
-                                         self.kwargs['llcrnrlon'],
-                                         self.kwargs['urcrnrlat'],
-                                         self.kwargs['urcrnrlon']))
+        logging.debug("corner coordinates (lat/lon): ll(%.2f,%.2f), ur(%.2f,%.2f)",
+                      self.kwargs['llcrnrlat'], self.kwargs['llcrnrlon'],
+                      self.kwargs['urcrnrlat'], self.kwargs['urcrnrlon'])
 
         if self.kwargs["projection"] in ["cyl"]:
             # Latitudes in cylindrical projection need to be within -90..90.
@@ -453,8 +451,8 @@ class MapCanvas(basemap.Basemap):
                 # newer Matplotlib versions: this causes an exception when
                 # the user zooms/pans..
                 self.map_boundary.remove()
-            except:
-                pass
+            except Exception, ex:
+                logging.debug("wild exception catched: %s", ex)
 
         cont_vis = self.appearance["fill_continents"]
         self.set_fillcontinents_visible(False)
@@ -539,11 +537,11 @@ class MapCanvas(basemap.Basemap):
         item = index1.internalPointer()
         item2 = index2.internalPointer()
         if isinstance(item, titree.LagrantoMapItem):
-            lastChange = self.traj_item_tree.getLastChange()
+            last_change = self.traj_item_tree.getLastChange()
             # Update the given item or the entire tree if the two given
             # items are different.
             self.update_trajectory_items(item=item if item == item2 else None,
-                                         mode=lastChange)
+                                         mode=last_change)
 
     def update_trajectory_items(self, item=None, mode="DRAW_EVERYTHING"):
         """Draw or update map elements.
@@ -579,8 +577,8 @@ class MapCanvas(basemap.Basemap):
         if not self.traj_item_tree:
             return
 
-        logging.debug("updating trajectory items on map <%s>, mode %s" %
-                      (self.identifier, mode))
+        logging.debug("updating trajectory items on map <%s>, mode %s",
+                      self.identifier, mode)
 
         # If no item is given start at the root of the 'traj_item_tree'.
         if not item:
@@ -599,16 +597,16 @@ class MapCanvas(basemap.Basemap):
         # ancestors).
         #
         # Default values: The item is visible and inherits no other properties.
-        parentProperties = {"visible": True,
-                            "colour": None,
-                            "linestyle": None,
-                            "linewidth": None,
-                            "timeMarkerInterval": None}
+        parent_properties = {"visible": True,
+                             "colour": None,
+                             "linestyle": None,
+                             "linewidth": None,
+                             "timeMarkerInterval": None}
         parent = item.parent()  # this would be None if item == rootItem
         while parent:  # loop until root has been reached
             # Set visible to False if one item along the path to the root is
             # found to be set to invisible.
-            parentProperties["visible"] = parent.isVisible(self.identifier) and parentProperties["visible"]
+            parent_properties["visible"] = parent.isVisible(self.identifier) and parent_properties["visible"]
 
             # Inherit colour and time marker interval of the highest tree level
             # on which they are set (set the current property to the value
@@ -619,39 +617,39 @@ class MapCanvas(basemap.Basemap):
             for propName in ["colour", "linestyle", "linewidth",
                              "timeMarkerInterval"]:
                 prop = parent.getGxElementProperty("general", propName)
-                parentProperties[propName] = prop if prop \
-                    else parentProperties[propName]
+                parent_properties[propName] = prop if prop \
+                    else parent_properties[propName]
 
             # Move up one level.
             parent = parent.parent()
 
         # Iterative tree traversal: Put the item and its attributes on a
         # stack.
-        itemStack = [(item, parentProperties)]
+        item_stack = [(item, parent_properties)]
 
         # Operate on the items in the stack until the stack is empty.
-        while len(itemStack) > 0:
+        while len(item_stack) > 0:
 
             # Get a new item from the stack.
-            item, parentProperties = itemStack.pop()
+            item, parent_properties = item_stack.pop()
 
             # Its visibility is determined by its own visibility status
             # and that of its parent (i.e. the subtree it is part of).
-            itemProperties = {}
-            itemProperties["visible"] = item.isVisible(self.identifier) and parentProperties["visible"]
+            item_properties = {}
+            item_properties["visible"] = item.isVisible(self.identifier) and parent_properties["visible"]
             #
             for propName in ["colour", "linestyle", "linewidth",
                              "timeMarkerInterval"]:
-                itemProperties[propName] = parentProperties[propName] \
-                    if parentProperties[propName] \
+                item_properties[propName] = parent_properties[propName] \
+                    if parent_properties[propName] \
                     else item.getGxElementProperty("general",
                                                    propName)
 
             # Push all children of the current item onto the stack that are
             # instances of LagrantoMapItem (VariableItems are not plotted on
             # the map).
-            itemStack.extend([(child, itemProperties) for child in item.childItems
-                              if isinstance(child, titree.LagrantoMapItem)])
+            item_stack.extend([(child, item_properties) for child in item.childItems
+                               if isinstance(child, titree.LagrantoMapItem)])
 
             # Plotting and graphics property update operations can only be
             # performed for flight tracks and trajectories.
@@ -672,16 +670,16 @@ class MapCanvas(basemap.Basemap):
                         plt.setp(
                             item.getGxElementProperty(element,
                                                       "instance::%s" % self.identifier),
-                            visible=itemProperties["visible"],
-                            color=itemProperties["colour"],
-                            linestyle=itemProperties["linestyle"],
-                            linewidth=itemProperties["linewidth"])
+                            visible=item_properties["visible"],
+                            color=item_properties["colour"],
+                            linestyle=item_properties["linestyle"],
+                            linewidth=item_properties["linewidth"])
                     elif element == "timemarker":
                         plt.setp(
                             item.getGxElementProperty(element,
                                                       "instance::%s" % self.identifier),
-                            visible=itemProperties["visible"],
-                            color=itemProperties["colour"])
+                            visible=item_properties["visible"],
+                            color=item_properties["colour"])
 
             elif mode in ["FLIGHT_TRACK_ADDED", "TRAJECTORY_DIR_ADDED",
                           "MARKER_CHANGE", "DRAW_EVERYTHING"]:
@@ -700,37 +698,37 @@ class MapCanvas(basemap.Basemap):
                                                               "instance::%s" % self.identifier)
                         for instance in instances:
                             instance.remove()
-                    except (KeyError, ValueError) as e:
+                    except (KeyError, ValueError):
                         pass
                     # Plot new instances.
-                    plotInstance = self.plot(x, y,
-                                             color=itemProperties["colour"],
-                                             visible=itemProperties["visible"],
-                                             linestyle=itemProperties["linestyle"],
-                                             linewidth=itemProperties["linewidth"])
+                    plot_instance = self.plot(x, y,
+                                              color=item_properties["colour"],
+                                              visible=item_properties["visible"],
+                                              linestyle=item_properties["linestyle"],
+                                              linewidth=item_properties["linewidth"])
                     item.setGxElementProperty("lineplot",
                                               "instance::%s" % self.identifier,
-                                              plotInstance)
+                                              plot_instance)
 
                 # Get the indexes for the time markers. If no time markers should
                 # be drawn, 'None' is returned.
                 try:
                     # Try to remove an existing time marker instance from
                     # the plot.
-                    oldScatterInstance = item.getGxElementProperty("timemarker",
-                                                                   "instance::%s" % self.identifier)
-                    plt.setp(oldScatterInstance, visible=False)
-                    oldScatterInstance.remove()
-                except (KeyError, ValueError) as e:
+                    old_scatter_instance = item.getGxElementProperty("timemarker",
+                                                                     "instance::%s" % self.identifier)
+                    plt.setp(old_scatter_instance, visible=False)
+                    old_scatter_instance.remove()
+                except (KeyError, ValueError):
                     pass
                 imarker = item.getTimeMarkerIndexes()
                 if imarker is not None:
-                    scatterInstance = self.scatter(x[imarker], y[imarker],
-                                                   s=20, c=itemProperties["colour"],
-                                                   visible=itemProperties["visible"], linewidth=0)
+                    scatter_instance = self.scatter(x[imarker], y[imarker],
+                                                    s=20, c=item_properties["colour"],
+                                                    visible=item_properties["visible"], linewidth=0)
                     item.setGxElementProperty("timemarker",
                                               "instance::%s" % self.identifier,
-                                              scatterInstance)
+                                              scatter_instance)
 
         # Update the figure canvas.
         self.ax.figure.canvas.draw()
@@ -806,7 +804,7 @@ CLASS SatelliteOverpassPatch
 """
 
 
-class SatelliteOverpassPatch:
+class SatelliteOverpassPatch(object):
     """Represents a satellite overpass on the top view map (satellite
        track and, if available, swath).
     """
@@ -898,3 +896,77 @@ class SatelliteOverpassPatch:
                 element.remove()
             except:
                 pass
+
+
+class KMLPatch(object):
+    """
+    Represents a KML overlay.
+
+    KML overlay implementation is currently very crude and basic and most features are not supported.
+    """
+
+    def __init__(self, mapcanvas, kml):
+        self.map = mapcanvas
+        self.kml = kml
+        self.patches = []
+        self.draw()
+
+    def add_polygon(self, polygon):
+        coords = str(polygon.outerBoundaryIs.LinearRing.coordinates).split()
+        lons, lats = [[float(_x.split(",")[_i]) for _x in coords] for _i in range(2)]
+        x, y = self.map(lons, lats)
+        self.patches.append(self.map.plot(x, y, "-k"))
+
+    def add_point(self, point):
+        coords = str(point.coordinates).split()
+        lons, lats = [[float(_x.split(",")[_i]) for _x in coords] for _i in range(2)]
+        x, y = self.map(lons, lats)
+        self.patches.append(self.map.plot(x, y, "ok"))
+
+    def parse_placemarks(self, placemarks):
+        for i in range(len(placemarks)):
+            placemark = placemarks[i]
+            if hasattr(placemark, "Polygon"):
+                self.add_polygon(placemark.Polygon)
+            if hasattr(placemark, "Point"):
+                self.add_point(placemark.Point)
+            if hasattr(placemark, "MultiGeometry"):
+                multigeometry = placemark.MultiGeometry
+                if hasattr(multigeometry, "Point"):
+                    for j in range(len(multigeometry.Point)):
+                        self.add_point(multigeometry.Point[j])
+                if hasattr(multigeometry, "Polygon"):
+                    for j in range(len(multigeometry.Polygon)):
+                        self.add_polygon(multigeometry.Polygon[j])
+
+    def search_placemarks(self, document):
+        if hasattr(document, "Placemark"):
+            self.parse_placemarks(document.Placemark)
+        if hasattr(document, "Folder"):
+            for j in range(len(document.Folder)):
+                self.search_placemarks(document.Folder[j])
+
+    def draw(self):
+        """Do the actual plotting of the patch.
+        """
+        # Plot satellite track.
+        self.search_placemarks(self.kml.Document)
+
+        self.map.ax.figure.canvas.draw()
+
+    def update(self):
+        """Removes the current plot of the patch and redraws the patch.
+           This is necessary, for instance, when the map projection and/or
+           extent has been changed.
+        """
+        self.remove()
+        self.draw()
+
+    def remove(self):
+        """Remove this satellite patch from the map canvas.
+        """
+        for patch in self.patches:
+            for element in patch:
+                element.remove()
+        self.patches = []
+        self.map.ax.figure.canvas.draw()
