@@ -44,12 +44,12 @@ AUTHORS:
 """
 
 # standard library imports
-import sys
-import os
 import copy
+import importlib
 import logging
-
-from distutils.sysconfig import get_python_lib
+import os
+import sys
+import types
 
 from mslib import __version__
 from mslib.msui import ui_mainwindow as ui
@@ -61,13 +61,17 @@ from mslib.msui import sideview
 from mslib.msui import timeseriesview
 from mslib.msui import trajectories_tool
 from mslib.msui import loopview
-import mslib.mss_util
-from mslib.msui import wms_login_cache
+from mslib.msui import constants
 from mslib.mss_util import config_loader
 from mslib.msui import MissionSupportSystemDefaultConfig as mss_default
+from mslib.plugins.io.csv import load_from_csv, save_to_csv
+
 # related third party imports
 from PyQt4 import QtGui, QtCore  # Qt4 bindings
 
+# Add config path to PYTHONPATH so plugins located there may be found
+sys.path.append(constants.MSS_CONFIG_PATH)
+
 try:
     import view3D
 
@@ -91,9 +95,9 @@ print "Version:", __version__
 print "\nSystem is loading.."
 
 
-"""
-QActiveViewsListWidgetItem
-"""
+#
+# QActiveViewsListWidgetItem
+#
 
 
 class QActiveViewsListWidgetItem(QtGui.QListWidgetItem):
@@ -131,9 +135,9 @@ class QActiveViewsListWidgetItem(QtGui.QListWidgetItem):
             self.parent.emit(QtCore.SIGNAL("viewsChanged()"))
 
 
-"""
-QFlightTrackListWidgetItem
-"""
+#
+# QFlightTrackListWidgetItem
+#
 
 
 class QFlightTrackListWidgetItem(QtGui.QListWidgetItem):
@@ -173,9 +177,9 @@ class QFlightTrackListWidgetItem(QtGui.QListWidgetItem):
         item.flighttrack_model.setName(str(item.text()))
 
 
-"""
-About MSUI DIALOG
-"""
+#
+# About MSUI DIALOG
+#
 
 
 class MSS_AboutDialog(QtGui.QDialog, ui_ab.Ui_AboutMSUIDialog):
@@ -192,9 +196,9 @@ class MSS_AboutDialog(QtGui.QDialog, ui_ab.Ui_AboutMSUIDialog):
         self.setupUi(self)
         self.lblVersion.setText("Version: %s" % __version__)
 
-"""
-MAIN WINDOW
-"""
+#
+# MAIN WINDOW
+#
 
 
 class MSSMainWindow(QtGui.QMainWindow, ui.Ui_MSSMainWindow):
@@ -271,6 +275,74 @@ class MSSMainWindow(QtGui.QMainWindow, ui.Ui_MSSMainWindow):
         self.connect(self.listTools, QtCore.SIGNAL("itemActivated(QListWidgetItem *)"),
                      self.activateWindow)
 
+        self.addImportFilter("CSV", "csv", load_from_csv)
+        self.addExportFilter("CSV", "csv", save_to_csv)
+
+        import_plugins = config_loader(dataset="import_plugins", default={})
+        for name in import_plugins:
+            extension, module, function = import_plugins[name]
+            imported_module = importlib.import_module(module)
+            self.addImportFilter(name, extension, getattr(imported_module, function))
+
+        export_plugins = config_loader(dataset="export_plugins", default={})
+        for name in export_plugins:
+            extension, module, function = export_plugins[name]
+            imported_module = importlib.import_module(module)
+            self.addExportFilter(name, extension, getattr(imported_module, function))
+
+    def addImportFilter(self, name, extension, function):
+        full_name = "actionImportFlightTrack" + name.replace(" ", "")
+
+        if hasattr(self, full_name):
+            raise ValueError("'{}' has already been set!".format(full_name))
+
+        action = QtGui.QAction(self)
+        action.setObjectName(ui._fromUtf8(full_name))
+        action.setText(ui._translate("MSSMainWindow", name, None))
+        self.menuImport_Flight_Track.addAction(action)
+
+        def load_function_wrapper(self):
+            filename = QtGui.QFileDialog.getOpenFileName(
+                self, "Import Flight Track", "", name + " (*." + extension + ")")
+
+            if not filename.isEmpty():
+                filename = str(filename)
+                ft_name, new_waypoints = function(filename)
+                if not ft_name:
+                    ft_name = filename
+                waypoints_model = ft.WaypointsTableModel(name=ft_name, waypoints=new_waypoints)
+
+                listitem = QFlightTrackListWidgetItem(waypoints_model, self.listFlightTracks)
+                listitem.setFlags(QtCore.Qt.ItemIsEditable | QtCore.Qt.ItemIsSelectable | QtCore.Qt.ItemIsEnabled)
+
+                self.listFlightTracks.setCurrentItem(listitem)
+                self.setFlightTrackActive()
+
+        setattr(self, full_name, types.MethodType(load_function_wrapper, self))
+        self.connect(action, QtCore.SIGNAL("triggered()"), getattr(self, full_name))
+
+    def addExportFilter(self, name, extension, function):
+        full_name = "actionExportFlightTrack" + name.replace(" ", "")
+
+        if hasattr(self, full_name):
+            raise ValueError("'{}' has already been set!".format(full_name))
+
+        action = QtGui.QAction(self)
+        action.setObjectName(ui._fromUtf8(full_name))
+        action.setText(ui._translate("MSSMainWindow", name, None))
+        self.menuExport_Active_Flight_Track.addAction(action)
+
+        def save_function_wrapper(self):
+            filename = QtGui.QFileDialog.getSaveFileName(
+                self, "Export Flight Track", "", name + " (*." + extension + ")")
+
+            if not filename.isEmpty():
+                filename = str(filename)
+                function(filename, self.active_flight_track.name, self.active_flight_track.waypoints)
+
+        setattr(self, full_name, types.MethodType(save_function_wrapper, self))
+        self.connect(action, QtCore.SIGNAL("triggered()"), getattr(self, full_name))
+
     def closeEvent(self, event):
         """Ask user if he/she wants to close the application. If yes, also
            close all views that are open.
@@ -384,16 +456,23 @@ class MSSMainWindow(QtGui.QMainWindow, ui.Ui_MSSMainWindow):
         if template is None:
             template = []
             waypoints = config_loader(dataset="new_flighttrack_template", default=mss_default.new_flighttrack_template)
+            default_flightlevel = config_loader(dataset="new_flighttrack_flightlevel",
+                                                default=mss_default.new_flighttrack_flightlevel)
             for wp in waypoints:
-                template.append(ft.Waypoint(flightlevel=0, location=wp))
+                template.append(ft.Waypoint(flightlevel=default_flightlevel, location=wp))
+            if len(template) < 2:
+                QtGui.QMessageBox.critical(
+                    self, self.tr("flighttrack template"),
+                    self.tr("ERROR:Flighttrack template in configuration is too short. "
+                            "Please add at least two valid locations."),
+                    QtGui.QMessageBox.Ok)
 
         if filename:
             waypoints_model = ft.WaypointsTableModel(filename=filename)
         else:
             # Create a new flight track from the waypoints template.
             self.new_flight_track_counter += 1
-            waypoints_model = ft.WaypointsTableModel(name="new flight track (%i)" %
-                                                          self.new_flight_track_counter)
+            waypoints_model = ft.WaypointsTableModel(name="new flight track (%i)" % self.new_flight_track_counter)
             # Make a copy of the template. Otherwise all new flight tracks would
             # use the same data structure in memory.
             template_copy = copy.deepcopy(template)
@@ -401,8 +480,7 @@ class MSSMainWindow(QtGui.QMainWindow, ui.Ui_MSSMainWindow):
                                        waypoints=template_copy)
         # Create a new list entry for the flight track. Make the item name
         # editable.
-        listitem = QFlightTrackListWidgetItem(waypoints_model,
-                                              self.listFlightTracks)
+        listitem = QFlightTrackListWidgetItem(waypoints_model, self.listFlightTracks)
         listitem.setFlags(QtCore.Qt.ItemIsEditable | QtCore.Qt.ItemIsSelectable | QtCore.Qt.ItemIsEnabled)
 
         if activate:
@@ -416,12 +494,10 @@ class MSSMainWindow(QtGui.QMainWindow, ui.Ui_MSSMainWindow):
         Returns:
 
         """
-        filename = QtGui.QFileDialog.getOpenFileName(self,
-                                                     "Open Config file", "",
-                                                     "Supported files (*.json *.txt)"
-                                                     )
+        filename = QtGui.QFileDialog.getOpenFileName(
+            self, "Open Config file", "", "Supported files (*.json *.txt)")
         if not filename.isEmpty():
-            wms_login_cache.cached_config_file = str(filename)
+            constants.CACHED_CONFIG_FILE = str(filename)
 
     def openFlightTrack(self):
         """Slot for the 'Open Flight Track' menu entry. Opens a QFileDialog and
@@ -429,14 +505,16 @@ class MSSMainWindow(QtGui.QMainWindow, ui.Ui_MSSMainWindow):
         """
         filename = QtGui.QFileDialog.getOpenFileName(self,
                                                      "Open Flight Track", "",
-                                                     "Supported files (*.ftml *.csv *.txt)"
-                                                     ";;Flight track XML (*.ftml)"
-                                                     ";;CSV-file (*.csv)"
-                                                     ";;Text-file (*.txt)")
+                                                     "Flight track XML (*.ftml)")
 
         if not filename.isEmpty():
             filename = str(filename)
-            self.createNewFlightTrack(filename=filename, activate=True)
+            if filename.endswith('.ftml'):
+                self.createNewFlightTrack(filename=filename, activate=True)
+            else:
+                QtGui.QMessageBox.warning(self, "Open flight track",
+                                          "No supported file extension recognized!\n{:}".format(filename),
+                                          QtGui.QMessageBox.Ok)
 
     def closeFlightTrack(self):
         """Slot to close the currently selected flight track. Flight tracks can
@@ -472,10 +550,6 @@ class MSSMainWindow(QtGui.QMainWindow, ui.Ui_MSSMainWindow):
             if sel == QtGui.QMessageBox.Yes:
                 if filename.endswith('.ftml'):
                     self.active_flight_track.saveToFTML(filename)
-                elif filename.endswith('.csv'):
-                    self.active_flight_track.saveToCSV(filename)
-                elif filename.endswith('.txt'):
-                    self.active_flight_track.saveToText(filename)
                 else:
                     QtGui.QMessageBox.warning(self, "Save flight track",
                                               "Unknown file extension {:s}. Not saving!".format(filename),
@@ -486,23 +560,15 @@ class MSSMainWindow(QtGui.QMainWindow, ui.Ui_MSSMainWindow):
     def saveFlightTrackAs(self):
         """Slot for the 'Save Active Flight Track As' menu entry.
         """
-        filename = QtGui.QFileDialog.getSaveFileName(self,
-                                                     "Save Flight Track",
-                                                     os.path.join(self.lastSaveDir,
-                                                                  self.active_flight_track.name),
-                                                     "Flight track XML (*.ftml)"
-                                                     ";;CSV-file (*.csv)"
-                                                     ";;Text-file (*.txt)")
+        filename = QtGui.QFileDialog.getSaveFileName(
+            self, "Save Flight Track", os.path.join(self.lastSaveDir, self.active_flight_track.name),
+            "Flight track XML (*.ftml)")
 
         if not filename.isEmpty():
             filename = str(filename)
             self.lastSaveDir = os.path.dirname(filename)
             if filename.endswith('.ftml'):
                 self.active_flight_track.saveToFTML(filename)
-            elif filename.endswith('.csv'):
-                self.active_flight_track.saveToCSV(filename)
-            elif filename.endswith('.txt'):
-                self.active_flight_track.saveToText(filename)
             else:
                 QtGui.QMessageBox.warning(self, "Save flight track",
                                           "No supported file extension recognized!\n{:}".format(filename),
@@ -541,17 +607,17 @@ class MSSMainWindow(QtGui.QMainWindow, ui.Ui_MSSMainWindow):
 
 
 def main():
-    print "Launching user interface.."
-    app = QtGui.QApplication(sys.argv)
+    logging.info("Launching user interface...")
+    application = QtGui.QApplication(sys.argv)
     mainwindow = MSSMainWindow()
     mainwindow.createNewFlightTrack(activate=True)
     mainwindow.show()
-    sys.exit(app.exec_())
+    sys.exit(application.exec_())
 
 
-"""
-MAIN PROGRAM
-"""
+#
+# MAIN PROGRAM
+#
 
 if __name__ == "__main__":
     # Log everything, and send it to stderr.
